/**
 * Laser cuttable template for building a shelf speaker with
 * Dynavox AMT-1 and Wavecor WF145WA05
 */

B = 12.7; // Bushing outer diameter
M = 6.35; // Mill diameter
J = 100; // Mill pad
T = 21; // Material thickness
I = 320; // Internal dimension
A = 5; // Alignment pad size
P = 17; // Alignment pad placement
O = I + 2 * T; // Outer dimensions
BD = B - M; // Bushing offset

W = 200 - 40; // Internal width
H = 350 - 40; // Internal height/depth

echo("Internal volume", I*I*I/1000000, "L");

module sam300d_flush_mount() {
    offset(r=BD) square([255, 188], center=true);
}

// Side panels
translate([I+J/2, 0]) {
  difference() {
    square([H - BD, H + 100], center=true);
    translate([-H/2 + 100 , -H/2 + 60]) circle(d=100, $fn=100); // !!!
    offset(r=BD/2) square([80+M,M], center=true);
   
      
    // Alignment squares
    translate([O/2,0]) rotate(45) square(A, center=true);
    translate([-O/2,0]) rotate(45) square(A, center=true);
    translate([0,I/2-P]) rotate(45) square(A, center=true);
    translate([0,-I/2+P]) rotate(45) square(A, center=true);
    translate([I/2,I/2-P]) rotate(45) square(A, center=true);
    translate([I/2,-I/2+P]) rotate(45) square(A, center=true);
    translate([-I/2,I/2-P]) rotate(45) square(A, center=true);
    translate([-I/2,-I/2+P]) rotate(45) square(A, center=true);
  }
}

// Back face + bottom/top cutout
translate([-I-J/2, 0])
difference() {
  square([W - BD, H + 100], center=true);
  offset(r=BD/2)  square([93 - BD, 80 - BD], center=true);
    translate([0,H/2]) rotate(45) square(A, center=true);
    translate([0,-H/2]) rotate(45) square(A, center=true);
    translate([-W/2+P,0]) rotate(45) square(A, center=true);
    translate([W/2-P,0]) rotate(45) square(A, center=true);

}

// Mounting holes
difference() {
  square([W, H], center=true);
    
  // Tweeter
  translate([0, H/2-80]) {
      circle(d=65 + BD, $fn=100);
      translate([-56/2,-56/2]) circle(d=4, $fn=30);
      translate([56/2,-56/2]) circle(d=4, $fn=30);
      translate([-56/2,56/2]) circle(d=4, $fn=30);
      translate([56/2,56/2]) circle(d=4, $fn=30);
    
  }
  
  // Woofer
  translate([0, H/2-200]) {
    circle(d=118 + BD, $fn=100);
    for ( i = [45 : 90 : 360] ){
      rotate(i) translate([138/2,0]) circle(d=4, $fn=30);
    }
    
  }
}